==> piwigo-2.5.3.zip: piwigo/language/kn_IN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Start Install'] = 'ಸ್ಥಾಪನಾ ಕಾರ್ಯವನ್ನು ಆರಂಭಿಸಿ';
$lang['verification'] = 'ಪರಿಶೀಲನೆ';
$lang['user password given by your host provider'] = 'ಹೋಸ್ಟ್ ಪ್ರೊವೈಡರ್ ಒದಗಿಸಿರುವ ನಿಮ್ಮ ಬಳಕೆದಾರರ ಪ್ರವೇಶಪದ ';
$lang['user login given by your host provider'] = 'ಹೋಸ್ಟ್ ಪ್ರೊವೈಡರ್ ಒದಗಿಸಿರುವ ನಿಮ್ಮ ಬಳಕೆದಾರರ ಲಾಗಿನ್';
$lang['please enter your password again'] = 'ನಿಮ್ಮ ಪ್ರವೇಶಪದವನ್ನು ಮತ್ತೊಮ್ಮೆ ನಮೂದಿಸಿ';
$lang['enter a login for webmaster'] = 'ವೆಬ್ ಮಾಸ್ಟರ್ ನ ಲಾಗಿನ್ ಅನ್ನು ನಮೂದಿಸಿ';
$lang['Welcome to your new installation of Piwigo!'] = 'ನಿಮ್ಮ ಹೊಸ Piwigo ಸ್ಥಾಪನಾ ಕಾರ್ಯಕ್ಕೆ ಸುಸ್ವಾಗತ';
$lang['Welcome to my photo gallery'] = 'ನನ್ನ ಚಿತ್ರಶಾಲೆ (ಗ್ಯಾಲರಿ) ಗೆ ಸುಸ್ವಾಗತ.';
$lang['User'] = 'ಬಳಕೆದಾರ';
$lang['Sorry!'] = 'ಕ್ಷಮಿಸಿ!';
$lang['Default gallery language'] = 'ಚಿತ್ರಶಾಲೆ (ಗ್ಯಾಲರಿ)ಯ  ಪೂರ್ವನಿಯೋಜಿತ ಭಾಷೆ';
$lang['Host'] = 'ಹೋಸ್ಟ್';
$lang['Installation'] = 'ಸ್ಥಾಪನೆ';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'ಸಹಾಯ ಬೇಕೆ? ನಿಮ್ಮ ಪ್ರಶ್ನೆಗಳನ್ನು  <a href="%s">Piwigo message board</a> ನಲ್ಲಿ ಕೇಳಿ.';
$lang['Just another Piwigo gallery'] = 'ಇದು ನಿಮ್ಮದೇ  Piwigo ಚಿತ್ರಶಾಲೆ (ಗ್ಯಾಲರಿ)';
$lang['Database name'] = 'ಡೇಟಾಬೇಸಿನ ಹೆಸರು';
$lang['Can\'t connect to server'] = 'ಸರ್ವರ್ ನೊಂದಿಗೆ ಸಂಪರ್ಕಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.';
$lang['Congratulations, Piwigo installation is completed'] = 'ಅಭಿನಂದನೆಗಳು, ನಿಮ್ಮ Piwigo ದ ಸ್ಥಾಪನೆ ಇದೀಗ ಯಶಸ್ವಿಯಾಗಿ ಮುಗಿದಿದೆ.';
$lang['Admin configuration'] = 'ನಿರ್ವಹಣೆಗಾರರ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳು (Admin configuration)';
$lang['Basic configuration'] = 'ಮೂಲ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳು (Basic configuration)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'local/config/database.inc.php ಕಾರ್ಯಸಿದ್ಧತೆ ಕಡತ ವನ್ನು ರೂಪಿಸುವಲ್ಲಿ ವಿಫಲ.';
$lang['Database configuration'] = 'ಡೇಟಾಬೇಸ್ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳು (Database configuration)';
$lang['Download the config file'] = 'ಕಾರ್ಯಸಿದ್ಧತೆ ಕಡತ (config file) ವನ್ನು ಇಳಿಸಿಕೊಳ್ಳಿ';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'ಗಮನಿಸಿ : ನಿಮ್ಮ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳನ್ನು ನೀವೇ ಬದಲಾಯಿಸಬಹುದು ಮತ್ತು ಆನಂತರ ಅದರ ಬಳಕೆಗಾಗಿ Piwigo ಅನ್ನು ಮರುಚಾಲಿಸಿ.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = '.htaccess ಕಡತವನ್ನು ರೂಪಿಸುವುದರ ಅಥವಾ ಮಾರ್ಪಡಿಸುವುದರ ಮೂಲಕ Piwigo ನಿಮ್ಮ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳನ್ನು  PHP 5 ಗೆ ವರ್ಗಾಯಿಸಲು ಪ್ರಯತ್ನಿಸುತ್ತದೆ.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ಗೆ PHP 5  ಅನ್ನು ಸಿಧ್ಧಗೊಳಿಸಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.';
$lang['Try to configure PHP 5'] = 'PHP 5  ಅನ್ನು ಸಿಧ್ಧಗೊಳಿಸಲು ಪ್ರಯತ್ನಿಸಿ.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'ಸ್ಥ್ಪಾಪನಾ ಕಾರ್ಯದಲ್ಲಿ, ನೀವು ಕಾರ್ಯಸಿದ್ಧತೆ ಕಡತ ವನ್ನು ಇಳಿಸಿಕೊಳ್ಳಬಹುದು ಮತ್ತು ಅದನ್ನು local/config ಡೈರಕ್ಟರಿಗೆ ವರ್ಗಾಯಿಸಬಹುದು.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning: database.inc.php must only contain what is in the textarea, no line return or space character)';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'ಡೇಟಾಬೇಸ್ ಟೇಬಲ್ ಗಳ ಹೆಸರುಗಳಿಗೆ ಪೂರ್ವಪ್ರತ್ಯಯ ( prefix ) ಗಳನ್ನು ಅಳವಡಿಸುತ್ತದೆ. (ಟೇಬಲ್ ಗಳನ್ನು ಉತ್ತಮ ರೀತಿಯಲ್ಲಿ ನಿರ್ವಹಿಸಲು ಇದು ನಿಮಗೆ ಸಹಾಯಕ)';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'ಯಾವುದೇ ಬಗೆಯ ಸಹಾಯಕ್ಕೆ ನಮ್ಮ ಈ ಚರ್ಚಾವೇದಿಕೆ (forum) ಗಳನ್ನು ಬಳಸುವಲ್ಲಿ ಹಿಂಜರಿಯಬೇಡಿ : %s';
$lang['Database table prefix'] = 'ಡೇಟಾಬೇಸ್ ಟೇಬಲ್ ಗಳ ಪೂರ್ವಪ್ರತ್ಯಯ ( prefix )';
$lang['Password ']['confirm'] = 'ಪ್ರವೇಶಪದ [ಖಾತ್ರಿ]';
$lang['PHP 5 is required'] = 'PHP 5 ಅತ್ಯಗತ್ಯವಾಗಿದೆ.';
$lang['Keep it confidential, it enables you to access administration panel'] = 'ಈ ವಿವರಗಳನ್ನು ಸುರಕ್ಷಿತವಾಗಿ ಇಡಿ, ಇದು ನಿಮಗೆ ನಿರ್ವಹಣಾ ಪ್ಯಾನೆಲ್ ಅನ್ನು ಬಳಸುವಾಗ ಉಪಯೊಗಕ್ಕೆ ಬರುತ್ತದೆ.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'ಈ ವಿವರಗಳು ನೋಡುಗರಿಗೆ ಲಭ್ಯವಿರುತ್ತವೆ, ಜಾಲತಾಣ ನಿರ್ವಹಣಾ ಕಾರ್ಯಕ್ಕೆ ಇದು ಅತ್ಯಗತ್ಯ.';
$lang['It appears your webhost is currently running PHP %s.'] = 'ನಿಮ್ಮ ವೆಬ್ ಹೋಸ್ಟ್ ಸಧ್ಯಕ್ಕೆ PHP %s ಅನ್ನು ಬಳಸುತ್ತಿದೆ.';
$lang['Hope to see you back soon.'] = 'ಮತ್ತೆ ಸಧ್ಯದಲ್ಲೇ ಭೇಟಿಯಾಗೋಣ.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'ಸರ್ವರ್ ಅನ್ನು ಯಶಸ್ವಿಯಾಗಿ ಸಂಪರ್ಕಿಸಲಾಗಿದೆ, ಆದರೆ ಡೇಟಾಬೇಸ್ ಅನ್ನು ಸಂಪರ್ಕಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'ತಾಣ ನಿರ್ವಹಣೆಗಾರರ (ಸೈಟ್ ಅಡ್ಮಿನ್) ನ್ನು ಸಂಪರ್ಕಿಸಲು ಬಳಕೆದಾರರು/ನೋಡುಗರು ಈ ಮಿಂಚೆ ವಿಳಾಸವನ್ನು ಬಳಸಬಹುದಾಗಿದೆ';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'PHP 5 ಗೆ ನೀವು ಹೇಗೆ ಬದಲಾಯಿಸಿಕೊಳ್ಳ ಬಹುದು ಎಂಬುದರ ವಿವರಗಳನ್ನು ನಿಮ್ಮ ಹೋಸ್ಟಿಂಗ್ ಪ್ರೊವೈಡರ್ ಅವರ ಸಹಾಯದಲ್ಲಿ ನೋಡಿರಿ.';
$lang['also given by your host provider'] = 'ಹಾಗೂ ನಿಮ್ಮ ಹೋಸ್ಟಿಂಗ್ ಪ್ರೊವೈಡರ್ ಅವರಿಂದ ಪೂರೈಸಿದೆ';
$lang['webmaster login can\'t contain characters \' or "'] = 'ವೆಬ್ ಮಾಸ್ಟರ್ ಲಾಗಿನ್ \' ಅಥವಾ " ಸಂಕೇತಾಕ್ಷರಗಳನ್ನು ಹೊಂದಿರಬಾರದು';
?>

==> piwigo-16.1.0.zip: piwigo/language/kn_IN/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Start Install'] = 'ಸ್ಥಾಪನಾ ಕಾರ್ಯವನ್ನು ಆರಂಭಿಸಿ';
$lang['verification'] = 'ಪರಿಶೀಲನೆ';
$lang['user password given by your host provider'] = 'ಹೋಸ್ಟ್ ಪ್ರೊವೈಡರ್ ಒದಗಿಸಿರುವ ನಿಮ್ಮ ಬಳಕೆದಾರರ ಪ್ರವೇಶಪದ ';
$lang['user login given by your host provider'] = 'ಹೋಸ್ಟ್ ಪ್ರೊವೈಡರ್ ಒದಗಿಸಿರುವ ನಿಮ್ಮ ಬಳಕೆದಾರರ ಲಾಗಿನ್';
$lang['please enter your password again'] = 'ನಿಮ್ಮ ಪ್ರವೇಶಪದವನ್ನು ಮತ್ತೊಮ್ಮೆ ನಮೂದಿಸಿ';
$lang['enter a login for webmaster'] = 'ವೆಬ್ ಮಾಸ್ಟರ್ ನ ಲಾಗಿನ್ ಅನ್ನು ನಮೂದಿಸಿ';
$lang['Welcome to your new installation of Piwigo!'] = 'ನಿಮ್ಮ ಹೊಸ Piwigo ಸ್ಥಾಪನಾ ಕಾರ್ಯಕ್ಕೆ ಸುಸ್ವಾಗತ';
$lang['Welcome to my photo gallery'] = 'ನನ್ನ ಚಿತ್ರಶಾಲೆ (ಗ್ಯಾಲರಿ) ಗೆ ಸುಸ್ವಾಗತ.';
$lang['User'] = 'ಬಳಕೆದಾರ';
$lang['Sorry!'] = 'ಕ್ಷಮಿಸಿ!';
$lang['Default gallery language'] = 'ಚಿತ್ರಶಾಲೆ (ಗ್ಯಾಲರಿ)ಯ  ಪೂರ್ವನಿಯೋಜಿತ ಭಾಷೆ';
$lang['Host'] = 'ಹೋಸ್ಟ್';
$lang['Installation'] = 'ಸ್ಥಾಪನೆ';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'ಸಹಾಯ ಬೇಕೆ? ನಿಮ್ಮ ಪ್ರಶ್ನೆಗಳನ್ನು  <a href="%s">Piwigo message board</a> ನಲ್ಲಿ ಕೇಳಿ.';
$lang['Just another Piwigo gallery'] = 'ಇದು ನಿಮ್ಮದೇ  Piwigo ಚಿತ್ರಶಾಲೆ (ಗ್ಯಾಲರಿ)';
$lang['Database name'] = 'ಡೇಟಾಬೇಸಿನ ಹೆಸರು';
$lang['Can\'t connect to server'] = 'ಸರ್ವರ್ ನೊಂದಿಗೆ ಸಂಪರ್ಕಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.';
$lang['Congratulations, Piwigo installation is completed'] = 'ಅಭಿನಂದನೆಗಳು, ನಿಮ್ಮ Piwigo ದ ಸ್ಥಾಪನೆ ಇದೀಗ ಯಶಸ್ವಿಯಾಗಿ ಮುಗಿದಿದೆ.';
$lang['Admin configuration'] = 'ನಿರ್ವಹಣೆಗಾರರ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳು (Admin configuration)';
$lang['Basic configuration'] = 'ಮೂಲ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳು (Basic configuration)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'local/config/database.inc.php ಕಾರ್ಯಸಿದ್ಧತೆ ಕಡತ ವನ್ನು ರೂಪಿಸುವಲ್ಲಿ ವಿಫಲ.';
$lang['Database configuration'] = 'ಡೇಟಾಬೇಸ್ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳು (Database configuration)';
$lang['Download the config file'] = 'ಕಾರ್ಯಸಿದ್ಧತೆ ಕಡತ (config file) ವನ್ನು ಇಳಿಸಿಕೊಳ್ಳಿ';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'ಗಮನಿಸಿ : ನಿಮ್ಮ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳನ್ನು ನೀವೇ ಬದಲಾಯಿಸಬಹುದು ಮತ್ತು ಆನಂತರ ಅದರ ಬಳಕೆಗಾಗಿ Piwigo ಅನ್ನು ಮರುಚಾಲಿಸಿ.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = '.htaccess ಕಡತವನ್ನು ರೂಪಿಸುವುದರ ಅಥವಾ ಮಾರ್ಪಡಿಸುವುದರ ಮೂಲಕ Piwigo ನಿಮ್ಮ ಕಾರ್ಯ ಸಿದ್ಧತೆಗಳನ್ನು  PHP 5.2 ಗೆ ವರ್ಗಾಯಿಸಲು ಪ್ರಯತ್ನಿಸುತ್ತದೆ.';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo ಗೆ PHP 5.2  ಅನ್ನು ಸಿಧ್ಧಗೊಳಿಸಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.';
$lang['Try to configure PHP 5'] = 'PHP 5.2  ಅನ್ನು ಸಿಧ್ಧಗೊಳಿಸಲು ಪ್ರಯತ್ನಿಸಿ.';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'ಸ್ಥ್ಪಾಪನಾ ಕಾರ್ಯದಲ್ಲಿ, ನೀವು ಕಾರ್ಯಸಿದ್ಧತೆ ಕಡತ ವನ್ನು ಇಳಿಸಿಕೊಳ್ಳಬಹುದು ಮತ್ತು ಅದನ್ನು local/config ಡೈರಕ್ಟರಿಗೆ ವರ್ಗಾಯಿಸಬಹುದು.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning: database.inc.php must only contain what is in the textarea, no line return or space character)';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'ಡೇಟಾಬೇಸ್ ಟೇಬಲ್ ಗಳ ಹೆಸರುಗಳಿಗೆ ಪೂರ್ವಪ್ರತ್ಯಯ ( prefix ) ಗಳನ್ನು ಅಳವಡಿಸುತ್ತದೆ. (ಟೇಬಲ್ ಗಳನ್ನು ಉತ್ತಮ ರೀತಿಯಲ್ಲಿ ನಿರ್ವಹಿಸಲು ಇದು ನಿಮಗೆ ಸಹಾಯಕ)';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'ಯಾವುದೇ ಬಗೆಯ ಸಹಾಯಕ್ಕೆ ನಮ್ಮ ಈ ಚರ್ಚಾವೇದಿಕೆ (forum) ಗಳನ್ನು ಬಳಸುವಲ್ಲಿ ಹಿಂಜರಿಯಬೇಡಿ : %s';
$lang['Database table prefix'] = 'ಡೇಟಾಬೇಸ್ ಟೇಬಲ್ ಗಳ ಪೂರ್ವಪ್ರತ್ಯಯ ( prefix )';
$lang['Password ']['confirm'] = 'ಪ್ರವೇಶಪದ [ಖಾತ್ರಿ]';
$lang['PHP 5 is required'] = 'PHP 5.2 ಅತ್ಯಗತ್ಯವಾಗಿದೆ.';
$lang['Keep it confidential, it enables you to access administration panel'] = 'ಈ ವಿವರಗಳನ್ನು ಸುರಕ್ಷಿತವಾಗಿ ಇಡಿ, ಇದು ನಿಮಗೆ ನಿರ್ವಹಣಾ ಪ್ಯಾನೆಲ್ ಅನ್ನು ಬಳಸುವಾಗ ಉಪಯೊಗಕ್ಕೆ ಬರುತ್ತದೆ.';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'ಈ ವಿವರಗಳು ನೋಡುಗರಿಗೆ ಲಭ್ಯವಿರುತ್ತವೆ, ಜಾಲತಾಣ ನಿರ್ವಹಣಾ ಕಾರ್ಯಕ್ಕೆ ಇದು ಅತ್ಯಗತ್ಯ.';
$lang['It appears your webhost is currently running PHP %s.'] = 'ನಿಮ್ಮ ವೆಬ್ ಹೋಸ್ಟ್ ಸಧ್ಯಕ್ಕೆ PHP %s ಅನ್ನು ಬಳಸುತ್ತಿದೆ.';
$lang['Hope to see you back soon.'] = 'ಮತ್ತೆ ಸಧ್ಯದಲ್ಲೇ ಭೇಟಿಯಾಗೋಣ.';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'ಸರ್ವರ್ ಅನ್ನು ಯಶಸ್ವಿಯಾಗಿ ಸಂಪರ್ಕಿಸಲಾಗಿದೆ, ಆದರೆ ಡೇಟಾಬೇಸ್ ಅನ್ನು ಸಂಪರ್ಕಿಸಲು ಸಾಧ್ಯವಾಗುತ್ತಿಲ್ಲ.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'ತಾಣ ನಿರ್ವಹಣೆಗಾರರ (ಸೈಟ್ ಅಡ್ಮಿನ್) ನ್ನು ಸಂಪರ್ಕಿಸಲು ಬಳಕೆದಾರರು/ನೋಡುಗರು ಈ ಮಿಂಚೆ ವಿಳಾಸವನ್ನು ಬಳಸಬಹುದಾಗಿದೆ';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'PHP 5.2 ಗೆ ನೀವು ಹೇಗೆ ಬದಲಾಯಿಸಿಕೊಳ್ಳ ಬಹುದು ಎಂಬುದರ ವಿವರಗಳನ್ನು ನಿಮ್ಮ ಹೋಸ್ಟಿಂಗ್ ಪ್ರೊವೈಡರ್ ಅವರ ಸಹಾಯದಲ್ಲಿ ನೋಡಿರಿ.';
$lang['also given by your host provider'] = 'ಹಾಗೂ ನಿಮ್ಮ ಹೋಸ್ಟಿಂಗ್ ಪ್ರೊವೈಡರ್ ಅವರಿಂದ ಪೂರೈಸಿದೆ';
$lang['webmaster login can\'t contain characters \' or "'] = 'ವೆಬ್ ಮಾಸ್ಟರ್ ಲಾಗಿನ್ \' ಅಥವಾ " ಸಂಕೇತಾಕ್ಷರಗಳನ್ನು ಹೊಂದಿರಬಾರದು';
$lang['localhost or other, supplied by your host provider'] = 'ನಿಮ್ಮ ಹೋಸ್ಟ್ ಪ್ರೊವೈಡರ್ ಒದಗಿಸಿರುವ ಲೋಕಲ್ ಹೋಸ್ಟ್ ಅಥವಾ ಇತರೆ';
